
Linux eduVPN client and Python API
==================================

This is the GNU/Linux desktop client for eduVPN. It also is a Python client API.

Read more about eduVPN on the eduVPN website http://eduvpn.org/.

Installation
============

The python eduVPN client is available on pypi:

```bash
$ pip install python-eduvpn
```

Or to install the Graphical User Interface and/or the Network manager integration:

```bash
$ pip install "python-eduvpn[gui]"
```

For more detailed instruction you can find the full installation instructions [here](http://python-eduvpn-client.readthedocs.io/en/latest/introduction.html#installation) 
or in the doc directory of the repository.

Documentation
=============

You can find the documentation on [http://python-eduvpn-client.readthedocs.io](http://python-eduvpn-client.readthedocs.io).

